@@ -68,7 +68,7 @@ INSERT INTO "usage" VALUES(
     'EPSG','1024'  -- unknown
 );
 
-INSERT INTO "other_transformation" VALUES('PROJ','CRS84_TO_EPSG_4326','OGC:CRS84 to WGS 84',NULL,'EPSG','9843','Axis Order Reversal (2D)','OGC','CRS84','EPSG','4326',0.0,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
+INSERT INTO "other_transformation" VALUES('PROJ','CRS84_TO_EPSG_4326','OGC:CRS84 to WGS 84',NULL,'EPSG','9843','Axis Order Reversal (2D)','OGC','CRS84','EPSG','4326',0.0,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
 INSERT INTO "usage" VALUES(
     'PROJ',
     'CRS84_TO_EPSG_4326_USAGE',
@@ -79,7 +79,7 @@ INSERT INTO "usage" VALUES(
     'EPSG','1024'  -- unknown
 );
 
-INSERT INTO "other_transformation" VALUES('PROJ','CRS27_TO_EPSG_4267','OGC:CRS27 to NAD27',NULL,'EPSG','9843','Axis Order Reversal (2D)','OGC','CRS27','EPSG','4267',0.0,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
+INSERT INTO "other_transformation" VALUES('PROJ','CRS27_TO_EPSG_4267','OGC:CRS27 to NAD27',NULL,'EPSG','9843','Axis Order Reversal (2D)','OGC','CRS27','EPSG','4267',0.0,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
 INSERT INTO "usage" VALUES(
     'PROJ',
     'CRS27_TO_EPSG_4267_USAGE',
@@ -90,7 +90,7 @@ INSERT INTO "usage" VALUES(
     'EPSG','1024'  -- unknown
 );
 
-INSERT INTO "other_transformation" VALUES('PROJ','CRS83_TO_EPSG_4269','OGC:CRS83 to NAD83',NULL,'EPSG','9843','Axis Order Reversal (2D)','OGC','CRS83','EPSG','4269',0.0,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
+INSERT INTO "other_transformation" VALUES('PROJ','CRS83_TO_EPSG_4269','OGC:CRS83 to NAD83',NULL,'EPSG','9843','Axis Order Reversal (2D)','OGC','CRS83','EPSG','4269',0.0,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
 INSERT INTO "usage" VALUES(
     'PROJ',
     'CRS83_TO_EPSG_4269_USAGE',
@@ -170,6 +170,18 @@ INSERT INTO grid_transformation SELECT
     grid2_param_code,
     grid2_param_name,
     grid2_name,
+    param1_auth_name,
+    param1_code,
+    param1_name,
+    param1_value,
+    param1_uom_auth_name,
+    param1_uom_code,
+    param2_auth_name,
+    param2_code,
+    param2_name,
+    param2_value,
+    param2_uom_auth_name,
+    param2_uom_code,
     interpolation_crs_auth_name,
     interpolation_crs_code,
     operation_version,
@@ -210,6 +222,18 @@ INSERT INTO grid_transformation SELECT
     grid2_param_code,
     grid2_param_name,
     grid2_name,
+    param1_auth_name,
+    param1_code,
+    param1_name,
+    param1_value,
+    param1_uom_auth_name,
+    param1_uom_code,
+    param2_auth_name,
+    param2_code,
+    param2_name,
+    param2_value,
+    param2_uom_auth_name,
+    param2_uom_code,
     'EPSG' AS interpolation_crs_auth_name,
     8255 AS interpolation_crs_code,
     operation_version,
@@ -248,6 +272,18 @@ INSERT INTO grid_transformation SELECT
     grid2_param_code,
     grid2_param_name,
     grid2_name,
+    param1_auth_name,
+    param1_code,
+    param1_name,
+    param1_value,
+    param1_uom_auth_name,
+    param1_uom_code,
+    param2_auth_name,
+    param2_code,
+    param2_name,
+    param2_value,
+    param2_uom_auth_name,
+    param2_uom_code,
     'EPSG' AS interpolation_crs_auth_name,
     8255 AS interpolation_crs_code,
     operation_version,
@@ -286,6 +322,18 @@ INSERT INTO grid_transformation SELECT
     grid2_param_code,
     grid2_param_name,
     grid2_name,
+    param1_auth_name,
+    param1_code,
+    param1_name,
+    param1_value,
+    param1_uom_auth_name,
+    param1_uom_code,
+    param2_auth_name,
+    param2_code,
+    param2_name,
+    param2_value,
+    param2_uom_auth_name,
+    param2_uom_code,
     'EPSG' AS interpolation_crs_auth_name,
     8255 AS interpolation_crs_code,
     operation_version,
@@ -324,6 +372,18 @@ INSERT INTO grid_transformation SELECT
     grid2_param_code,
     grid2_param_name,
     grid2_name,
+    param1_auth_name,
+    param1_code,
+    param1_name,
+    param1_value,
+    param1_uom_auth_name,
+    param1_uom_code,
+    param2_auth_name,
+    param2_code,
+    param2_name,
+    param2_value,
+    param2_uom_auth_name,
+    param2_uom_code,
     'EPSG' AS interpolation_crs_auth_name,
     8255 AS interpolation_crs_code,
     operation_version,
@@ -362,6 +422,18 @@ INSERT INTO grid_transformation SELECT
     grid2_param_code,
     grid2_param_name,
     grid2_name,
+    param1_auth_name,
+    param1_code,
+    param1_name,
+    param1_value,
+    param1_uom_auth_name,
+    param1_uom_code,
+    param2_auth_name,
+    param2_code,
+    param2_name,
+    param2_value,
+    param2_uom_auth_name,
+    param2_uom_code,
     'EPSG' AS interpolation_crs_auth_name,
     8255 AS interpolation_crs_code,
     operation_version,
@@ -400,6 +472,18 @@ INSERT INTO grid_transformation SELECT
     grid2_param_code,
     grid2_param_name,
     grid2_name,
+    param1_auth_name,
+    param1_code,
+    param1_name,
+    param1_value,
+    param1_uom_auth_name,
+    param1_uom_code,
+    param2_auth_name,
+    param2_code,
+    param2_name,
+    param2_value,
+    param2_uom_auth_name,
+    param2_uom_code,
     'EPSG' AS interpolation_crs_auth_name,
     8255 AS interpolation_crs_code,
     operation_version,
@@ -554,6 +638,18 @@ SELECT
     gt.grid2_param_code,
     gt.grid2_param_name,
     gt.grid2_name,
+    gt.param1_auth_name,
+    gt.param1_code,
+    gt.param1_name,
+    gt.param1_value,
+    gt.param1_uom_auth_name,
+    gt.param1_uom_code,
+    gt.param2_auth_name,
+    gt.param2_code,
+    gt.param2_name,
+    gt.param2_value,
+    gt.param2_uom_auth_name,
+    gt.param2_uom_code,
     gt.interpolation_crs_auth_name,
     gt.interpolation_crs_code,
     gt.operation_version,
@@ -606,6 +702,18 @@ SELECT
     gt.grid2_param_code,
     gt.grid2_param_name,
     gt.grid2_name,
+    gt.param1_auth_name,
+    gt.param1_code,
+    gt.param1_name,
+    gt.param1_value,
+    gt.param1_uom_auth_name,
+    gt.param1_uom_code,
+    gt.param2_auth_name,
+    gt.param2_code,
+    gt.param2_name,
+    gt.param2_value,
+    gt.param2_uom_auth_name,
+    gt.param2_uom_code,
     gt.interpolation_crs_auth_name,
     gt.interpolation_crs_code,
     gt.operation_version,
