@@ -680,7 +680,8 @@ CREATE TABLE helmert_transformation_table(
 
     CONSTRAINT pk_helmert_transformation PRIMARY KEY (auth_name, code),
     CONSTRAINT fk_helmert_transformation_source_crs FOREIGN KEY (source_crs_auth_name, source_crs_code) REFERENCES geodetic_crs(auth_name, code) ON DELETE CASCADE,
-    CONSTRAINT fk_helmert_transformation_target_crs FOREIGN KEY (target_crs_auth_name, target_crs_code) REFERENCES geodetic_crs(auth_name, code) ON DELETE CASCADE,
+    -- below not true for EPSG:10905 ("ETRS89/DREF91/2016 to Asse 2025 + Asse 2025 height (1)") whose target CRS is a compound CRS
+    -- CONSTRAINT fk_helmert_transformation_target_crs FOREIGN KEY (target_crs_auth_name, target_crs_code) REFERENCES geodetic_crs(auth_name, code) ON DELETE CASCADE,
     CONSTRAINT fk_helmert_transformation_method FOREIGN KEY (method_auth_name, method_code) REFERENCES coordinate_operation_method(auth_name, code) ON DELETE CASCADE,
     --CONSTRAINT fk_helmert_transformation_coordinate_operation FOREIGN KEY (auth_name, code) REFERENCES coordinate_operation(auth_name, code) ON DELETE CASCADE,
     CONSTRAINT fk_helmert_translation_uom FOREIGN KEY (translation_uom_auth_name, translation_uom_code) REFERENCES unit_of_measure(auth_name, code) ON DELETE CASCADE,
@@ -853,6 +854,20 @@ CREATE TABLE grid_transformation(
     grid2_param_name TEXT,
     grid2_name TEXT,
 
+    param1_auth_name TEXT,
+    param1_code INTEGER_OR_TEXT,
+    param1_name TEXT,
+    param1_value FLOAT,
+    param1_uom_auth_name TEXT,
+    param1_uom_code INTEGER_OR_TEXT,
+
+    param2_auth_name TEXT,
+    param2_code INTEGER_OR_TEXT,
+    param2_name TEXT,
+    param2_value FLOAT,
+    param2_uom_auth_name TEXT,
+    param2_uom_code INTEGER_OR_TEXT,
+
     interpolation_crs_auth_name TEXT,
     interpolation_crs_code INTEGER_OR_TEXT,
 
@@ -975,6 +990,25 @@ CREATE TABLE other_transformation(
     param7_uom_auth_name TEXT,
     param7_uom_code INTEGER_OR_TEXT,
 
+    param8_auth_name TEXT,
+    param8_code INTEGER_OR_TEXT,
+    param8_name TEXT,
+    param8_value FLOAT,
+    param8_uom_auth_name TEXT,
+    param8_uom_code INTEGER_OR_TEXT,
+
+    param9_auth_name TEXT,
+    param9_code INTEGER_OR_TEXT,
+    param9_name TEXT,
+    param9_value FLOAT,
+    param9_uom_auth_name TEXT,
+    param9_uom_code INTEGER_OR_TEXT,
+
+    grid_param_auth_name TEXT,
+    grid_param_code INTEGER_OR_TEXT,
+    grid_param_name TEXT,
+    grid_name TEXT,
+
     interpolation_crs_auth_name TEXT,
     interpolation_crs_code INTEGER_OR_TEXT,
 
