@@ -281,7 +281,7 @@ int main(int argc, char **argv) {
     /* coverity[tainted_data] */
     o = opt_parse(argc, argv, "hlvq", "o", longflags, longkeys);
     if (nullptr == o)
-        return 0;
+        return 1;
 
     if (opt_given(o, "h") || argc == 1) {
         printf(usage, o->progname);
@@ -335,8 +335,9 @@ int main(int argc, char **argv) {
     for (i = 0; i < o->fargc; i++) {
         FILE *f = fopen(o->fargv[i], "rt");
         if (f == nullptr) {
-            fprintf(T.fout, "%sCannot open specified input file '%s' - bye!\n",
+            fprintf(stderr, "%sCannot open specified input file '%s' - bye!\n",
                     delim, o->fargv[i]);
+            free(o);
             return 1;
         }
         fclose(f);
