@@ -25,6 +25,7 @@
  * DEALINGS IN THE SOFTWARE.
  *****************************************************************************/
 
+#include <assert.h>
 #include <string.h>
 
 #include "proj.h"
@@ -41,28 +42,27 @@ static paralist **cache_paralist = nullptr;
 /*     Allocate a copy of a parameter list.                             */
 /************************************************************************/
 
-paralist *pj_clone_paralist( const paralist *list)
-{
-  paralist *list_copy = nullptr, *next_copy = nullptr;
+paralist *pj_clone_paralist(const paralist *list) {
+    paralist *list_copy = nullptr, *next_copy = nullptr;
 
-  for( ; list != nullptr; list = list->next )
-    {
-      paralist *newitem = (paralist *)
-	pj_malloc(sizeof(paralist) + strlen(list->param));
+    for (; list != nullptr; list = list->next) {
+        paralist *newitem =
+            (paralist *)malloc(sizeof(paralist) + strlen(list->param));
+        assert(newitem);
 
-      newitem->used = 0;
-      newitem->next = nullptr;
-      strcpy( newitem->param, list->param );
+        newitem->used = 0;
+        newitem->next = nullptr;
+        strcpy(newitem->param, list->param);
 
-      if( next_copy )
-	next_copy->next = newitem;
-      else
-	list_copy = newitem;
+        if (next_copy)
+            next_copy->next = newitem;
+        else
+            list_copy = newitem;
 
-      next_copy = newitem;
+        next_copy = newitem;
     }
 
-  return list_copy;
+    return list_copy;
 }
 
 /************************************************************************/
@@ -71,31 +71,28 @@ paralist *pj_clone_paralist( const paralist *list)
 /*      Clear out all memory held in the init file cache.               */
 /************************************************************************/
 
-void pj_clear_initcache()
-{
-    if( cache_alloc > 0 )
-    {
+void pj_clear_initcache() {
+    if (cache_alloc > 0) {
         int i;
 
         pj_acquire_lock();
 
-        for( i = 0; i < cache_count; i++ )
-        {
+        for (i = 0; i < cache_count; i++) {
             paralist *n, *t = cache_paralist[i];
-		
-            pj_dalloc( cache_key[i] );
+
+            free(cache_key[i]);
 
             /* free parameter list elements */
             for (; t != nullptr; t = n) {
                 n = t->next;
-                pj_dalloc(t);
+                free(t);
             }
         }
 
-        pj_dalloc( cache_key );
-        pj_dalloc( cache_paralist );
+        free(cache_key);
+        free(cache_paralist);
         cache_count = 0;
-        cache_alloc= 0;
+        cache_alloc = 0;
         cache_key = nullptr;
         cache_paralist = nullptr;
 
@@ -109,7 +106,7 @@ void pj_clear_initcache()
 /*      Search for a matching definition in the init cache.             */
 /************************************************************************/
 
-paralist *pj_search_initcache( const char *filekey )
+paralist *pj_search_initcache(const char *filekey)
 
 {
     int i;
@@ -117,12 +114,10 @@ paralist *pj_search_initcache( const char *filekey )
 
     pj_acquire_lock();
 
-    for( i = 0; result == nullptr && i < cache_count; i++)
-    {
-        if( strcmp(filekey,cache_key[i]) == 0 )
-	{
-            result = pj_clone_paralist( cache_paralist[i] );
-	}
+    for (i = 0; result == nullptr && i < cache_count; i++) {
+        if (strcmp(filekey, cache_key[i]) == 0) {
+            result = pj_clone_paralist(cache_paralist[i]);
+        }
     }
 
     pj_release_lock();
@@ -136,50 +131,49 @@ paralist *pj_search_initcache( const char *filekey )
 /*      Insert a paralist definition in the init file cache.            */
 /************************************************************************/
 
-void pj_insert_initcache( const char *filekey, const paralist *list )
+void pj_insert_initcache(const char *filekey, const paralist *list)
 
 {
     pj_acquire_lock();
 
-    /* 
+    /*
     ** Grow list if required.
     */
-    if( cache_count == cache_alloc )
-    {
+    if (cache_count == cache_alloc) {
         char **cache_key_new;
         paralist **cache_paralist_new;
 
         cache_alloc = cache_alloc * 2 + 15;
 
-        cache_key_new = (char **) pj_malloc(sizeof(char*) * cache_alloc);
-        if( cache_key && cache_count )
-        {
-            memcpy( cache_key_new, cache_key, sizeof(char*) * cache_count);
+        cache_key_new = (char **)malloc(sizeof(char *) * cache_alloc);
+        assert(cache_key_new);
+        if (cache_key && cache_count) {
+            memcpy(cache_key_new, cache_key, sizeof(char *) * cache_count);
         }
-        pj_dalloc( cache_key );
+        free(cache_key);
         cache_key = cache_key_new;
 
-        cache_paralist_new = (paralist **) 
-            pj_malloc(sizeof(paralist*) * cache_alloc);
-        if( cache_paralist && cache_count )
-        {
-            memcpy( cache_paralist_new, cache_paralist,
-                    sizeof(paralist*) * cache_count );
+        cache_paralist_new =
+            (paralist **)malloc(sizeof(paralist *) * cache_alloc);
+        assert(cache_paralist_new);
+        if (cache_paralist && cache_count) {
+            memcpy(cache_paralist_new, cache_paralist,
+                   sizeof(paralist *) * cache_count);
         }
-        pj_dalloc( cache_paralist );
+        free(cache_paralist);
         cache_paralist = cache_paralist_new;
     }
 
     /*
     ** Duplicate the filekey and paralist, and insert in cache.
     */
-    cache_key[cache_count] = (char *) pj_malloc(strlen(filekey)+1);
-    strcpy( cache_key[cache_count], filekey );
+    cache_key[cache_count] = (char *)malloc(strlen(filekey) + 1);
+    assert(cache_key[cache_count]);
+    strcpy(cache_key[cache_count], filekey);
 
-    cache_paralist[cache_count] = pj_clone_paralist( list );
+    cache_paralist[cache_count] = pj_clone_paralist(list);
 
     cache_count++;
 
     pj_release_lock();
 }
-
