@@ -13,7 +13,8 @@
 paralist *pj_mkparam(const char *str) {
     paralist *newitem;
 
-    if((newitem = (paralist *)malloc(sizeof(paralist) + strlen(str))) != nullptr) {
+    if ((newitem = (paralist *)malloc(sizeof(paralist) + strlen(str))) !=
+        nullptr) {
         newitem->used = 0;
         newitem->next = nullptr;
         if (*str == '+')
@@ -23,41 +24,41 @@ paralist *pj_mkparam(const char *str) {
     return newitem;
 }
 
-
-/* As pj_mkparam, but payload ends at first whitespace, rather than at end of <str> */
-paralist *pj_mkparam_ws (const char *str, const char **next_str) {
+/* As pj_mkparam, but payload ends at first whitespace, rather than at end of
+ * <str> */
+paralist *pj_mkparam_ws(const char *str, const char **next_str) {
     paralist *newitem;
     size_t len = 0;
 
-    if (nullptr==str)
+    if (nullptr == str)
         return nullptr;
 
     /* Find start and length of string */
-    while (isspace (*str))
+    while (isspace(*str))
         str++;
     if (*str == '+')
         str++;
     bool in_string = false;
-    for( ; str[len] != '\0'; len++ ) {
-        if( in_string ) {
-            if( str[len] == '"' && str[len+1] == '"' ) {
+    for (; str[len] != '\0'; len++) {
+        if (in_string) {
+            if (str[len] == '"' && str[len + 1] == '"') {
                 len++;
-            } else if( str[len] == '"' ) {
+            } else if (str[len] == '"') {
                 in_string = false;
             }
-        } else if( str[len] == '=' && str[len+1] == '"' ) {
+        } else if (str[len] == '=' && str[len + 1] == '"') {
             in_string = true;
-        } else if( isspace(str[len]) ) {
+        } else if (isspace(str[len])) {
             break;
         }
     }
 
-    if( next_str )
+    if (next_str)
         *next_str = str + len;
 
     /* Use calloc to automagically 0-terminate the copy */
-    newitem = (paralist *) calloc (1, sizeof(paralist) + len + 1);
-    if (nullptr==newitem)
+    newitem = (paralist *)calloc(1, sizeof(paralist) + len + 1);
+    if (nullptr == newitem)
         return nullptr;
     memcpy(newitem->param, str, len);
 
@@ -68,42 +69,43 @@ paralist *pj_mkparam_ws (const char *str, const char **next_str) {
 }
 
 /**************************************************************************************/
-paralist *pj_param_exists (paralist *list, const char *parameter) {
-/***************************************************************************************
-    Determine whether a given parameter exists in a paralist. If it does, return
-    a pointer to the corresponding list element - otherwise return 0.
+paralist *pj_param_exists(paralist *list, const char *parameter) {
+    /***************************************************************************************
+        Determine whether a given parameter exists in a paralist. If it does,
+    return a pointer to the corresponding list element - otherwise return 0.
 
-    In support of the pipeline syntax, the search is terminated once a "+step" list
-    element is reached, in which case a 0 is returned, unless the parameter
-    searched for is actually "step", in which case a pointer to the "step" list
-    element is returned.
+        In support of the pipeline syntax, the search is terminated once a
+    "+step" list element is reached, in which case a 0 is returned, unless the
+    parameter searched for is actually "step", in which case a pointer to the
+    "step" list element is returned.
 
-    This function is equivalent to the pj_param (...) call with the "opt" argument
-    set to the parameter name preceeeded by a 't'. But by using this one, one avoids
-    writing the code allocating memory for a new copy of parameter name, and prepending
-    the t (for compile time known names, this is obviously not an issue).
-***************************************************************************************/
+        This function is equivalent to the pj_param (...) call with the "opt"
+    argument set to the parameter name preceeeded by a 't'. But by using this
+    one, one avoids writing the code allocating memory for a new copy of
+    parameter name, and prepending the t (for compile time known names, this is
+    obviously not an issue).
+    ***************************************************************************************/
     paralist *next = list;
-    const char *c = strchr (parameter, '=');
-    size_t len = strlen (parameter);
+    const char *c = strchr(parameter, '=');
+    size_t len = strlen(parameter);
     if (c)
         len = c - parameter;
-    if (list==nullptr)
+    if (list == nullptr)
         return nullptr;
 
     for (next = list; next; next = next->next) {
-        if (0==strncmp (parameter, next->param, len) && (next->param[len]=='=' || next->param[len]==0)) {
+        if (0 == strncmp(parameter, next->param, len) &&
+            (next->param[len] == '=' || next->param[len] == 0)) {
             next->used = 1;
             return next;
         }
-        if (0==strcmp (parameter, "step"))
+        if (0 == strcmp(parameter, "step"))
             return nullptr;
     }
 
     return nullptr;
 }
 
-
 /************************************************************************/
 /*                              pj_param()                              */
 /*                                                                      */
@@ -124,37 +126,39 @@ paralist *pj_param_exists (paralist *list, const char *parameter) {
 /*                                                                      */
 /************************************************************************/
 
-PROJVALUE pj_param (PJ_CONTEXT *ctx, paralist *pl, const char *opt) {
+PROJVALUE pj_param(PJ_CONTEXT *ctx, paralist *pl, const char *opt) {
 
     int type;
     unsigned l;
     PROJVALUE value = {0};
 
-    if ( ctx == nullptr )
+    if (ctx == nullptr)
         ctx = pj_get_default_ctx();
 
     type = *opt++;
 
-    if (nullptr==strchr ("tbirds", type)) {
+    if (nullptr == strchr("tbirds", type)) {
         fprintf(stderr, "invalid request to pj_param, fatal\n");
         exit(1);
     }
 
-    pl = pj_param_exists (pl, opt);
+    pl = pj_param_exists(pl, opt);
     if (type == 't') {
         value.i = pl != nullptr;
         return value;
     }
 
     /* Not found */
-    if (nullptr==pl) {
+    if (nullptr == pl) {
         /* Return value after the switch, so that the return path is */
         /* taken in all cases */
         switch (type) {
-        case 'b': case 'i':
+        case 'b':
+        case 'i':
             value.i = 0;
             break;
-        case 'd': case 'r':
+        case 'd':
+        case 'r':
             value.f = 0.;
             break;
         case 's':
@@ -166,42 +170,44 @@ PROJVALUE pj_param (PJ_CONTEXT *ctx, paralist *pl, const char *opt) {
 
     /* Found parameter - now find its value */
     pl->used |= 1;
-    l = (int) strlen(opt);
+    l = (int)strlen(opt);
     opt = pl->param + l;
     if (*opt == '=')
         ++opt;
 
     switch (type) {
-    case 'i':    /* integer input */
+    case 'i': /* integer input */
         value.i = atoi(opt);
-        for( const char* ptr = opt; *ptr != '\0'; ++ptr )
-        {
-            if( !(*ptr >= '0' && *ptr <= '9') )
-            {
-                proj_context_errno_set (ctx, PROJ_ERR_INVALID_OP_ILLEGAL_ARG_VALUE);
+        for (const char *ptr = opt; *ptr != '\0'; ++ptr) {
+            if (!(*ptr >= '0' && *ptr <= '9')) {
+                proj_context_errno_set(ctx,
+                                       PROJ_ERR_INVALID_OP_ILLEGAL_ARG_VALUE);
                 value.i = 0;
             }
         }
         break;
-    case 'd':    /* simple real input */
+    case 'd': /* simple real input */
         value.f = pj_atof(opt);
         break;
-    case 'r':    /* degrees input */
+    case 'r': /* degrees input */
         value.f = dmstor_ctx(ctx, opt, nullptr);
         break;
-    case 's':    /* char string */
-        value.s = (char *) opt;
+    case 's': /* char string */
+        value.s = (char *)opt;
         break;
-    case 'b':    /* boolean */
+    case 'b': /* boolean */
         switch (*opt) {
-        case 'F': case 'f':
+        case 'F':
+        case 'f':
             value.i = 0;
             break;
-        case '\0': case 'T': case 't':
+        case '\0':
+        case 'T':
+        case 't':
             value.i = 1;
             break;
         default:
-            proj_context_errno_set (ctx, PROJ_ERR_INVALID_OP_ILLEGAL_ARG_VALUE);
+            proj_context_errno_set(ctx, PROJ_ERR_INVALID_OP_ILLEGAL_ARG_VALUE);
             value.i = 0;
             break;
         }
