@@ -1,4 +1,3 @@
-
 #include "proj.h"
 #include "proj_internal.h"
 #include <errno.h>
@@ -30,17 +29,18 @@ struct pj_laea_data {
 static PJ_XY laea_e_forward(PJ_LP lp, PJ *P) { /* Ellipsoidal, forward */
     PJ_XY xy = {0.0, 0.0};
     struct pj_laea_data *Q = static_cast<struct pj_laea_data *>(P->opaque);
-    double coslam, sinlam, sinphi, q, sinb = 0.0, cosb = 0.0, b = 0.0;
+    double coslam, sinlam, sinphi, cosphi, q, sinb = 0.0, cosb = 0.0, b = 0.0;
 
     coslam = cos(lp.lam);
     sinlam = sin(lp.lam);
     sinphi = sin(lp.phi);
-    q = pj_qsfn(sinphi, P->e, P->one_es);
+    cosphi = cos(lp.phi);
+    const double xi = pj_authalic_lat(lp.phi, sinphi, cosphi, Q->apa, P, Q->qp);
+    q = sin(xi) * Q->qp;
 
     if (Q->mode == pj_laea_ns::OBLIQ || Q->mode == pj_laea_ns::EQUIT) {
-        sinb = q / Q->qp;
-        const double cosb2 = 1. - sinb * sinb;
-        cosb = cosb2 > 0 ? sqrt(cosb2) : 0;
+        sinb = sin(xi);
+        cosb = cos(xi);
     }
 
     switch (Q->mode) {
@@ -181,7 +181,7 @@ static PJ_LP laea_e_inverse(PJ_XY xy, PJ *P) { /* Ellipsoidal, inverse */
         break;
     }
     lp.lam = atan2(xy.x, xy.y);
-    lp.phi = pj_authlat(asin(ab), Q->apa);
+    lp.phi = pj_authalic_lat_inverse(asin(ab), Q->apa, P, Q->qp);
     return lp;
 }
 
@@ -262,12 +262,12 @@ PJ *PJ_PROJECTION(laea) {
     else
         Q->mode = pj_laea_ns::OBLIQ;
     if (P->es != 0.0) {
-        double sinphi;
+        double sinphi, cosphi;
 
         P->e = sqrt(P->es);
-        Q->qp = pj_qsfn(1., P->e, P->one_es);
+        Q->qp = pj_authalic_lat_q(1.0, P);
         Q->mmf = .5 / (1. - P->es);
-        Q->apa = pj_authset(P->es);
+        Q->apa = pj_authalic_lat_compute_coeffs(P->n);
         if (nullptr == Q->apa)
             return pj_laea_destructor(P, PROJ_ERR_OTHER /*ENOMEM*/);
         switch (Q->mode) {
@@ -283,8 +283,11 @@ PJ *PJ_PROJECTION(laea) {
         case pj_laea_ns::OBLIQ:
             Q->rq = sqrt(.5 * Q->qp);
             sinphi = sin(P->phi0);
-            Q->sinb1 = pj_qsfn(sinphi, P->e, P->one_es) / Q->qp;
-            Q->cosb1 = sqrt(1. - Q->sinb1 * Q->sinb1);
+            cosphi = cos(P->phi0);
+            const double b1 =
+                pj_authalic_lat(P->phi0, sinphi, cosphi, Q->apa, P, Q->qp);
+            Q->sinb1 = sin(b1);
+            Q->cosb1 = cos(b1);
             Q->dd = cos(P->phi0) /
                     (sqrt(1. - P->es * sinphi * sinphi) * Q->rq * Q->cosb1);
             Q->ymf = (Q->xmf = Q->rq) / Q->dd;
