@@ -23,13 +23,12 @@
 ** TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 ** SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
-#define PJ_LIB__
-#include <errno.h>
+
 #include "proj.h"
 #include "proj_internal.h"
+#include <errno.h>
 #include <math.h>
 
-
 namespace { // anonymous namespace
 struct pj_opaque {
     double phic0;
@@ -39,14 +38,11 @@ struct pj_opaque {
 };
 } // anonymous namespace
 
-
 PROJ_HEAD(sterea, "Oblique Stereographic Alternative") "\n\tAzimuthal, Sph&Ell";
 
-
-
-static PJ_XY sterea_e_forward (PJ_LP lp, PJ *P) {          /* Ellipsoidal, forward */
-    PJ_XY xy = {0.0,0.0};
-    struct pj_opaque *Q = static_cast<struct pj_opaque*>(P->opaque);
+static PJ_XY sterea_e_forward(PJ_LP lp, PJ *P) { /* Ellipsoidal, forward */
+    PJ_XY xy = {0.0, 0.0};
+    struct pj_opaque *Q = static_cast<struct pj_opaque *>(P->opaque);
     double cosc, sinc, cosl, k;
 
     lp = pj_gauss(P->ctx, lp, Q->en);
@@ -54,8 +50,8 @@ static PJ_XY sterea_e_forward (PJ_LP lp, PJ *P) {          /* Ellipsoidal, forwa
     cosc = cos(lp.phi);
     cosl = cos(lp.lam);
     const double denom = 1. + Q->sinc0 * sinc + Q->cosc0 * cosc * cosl;
-    if( denom == 0.0 ) {
-        proj_errno_set(P, PJD_ERR_TOLERANCE_CONDITION);
+    if (denom == 0.0) {
+        proj_errno_set(P, PROJ_ERR_COORD_TRANSFM_OUTSIDE_PROJECTION_DOMAIN);
         return proj_coord_error().xy;
     }
     k = P->k0 * Q->R2 / denom;
@@ -64,20 +60,20 @@ static PJ_XY sterea_e_forward (PJ_LP lp, PJ *P) {          /* Ellipsoidal, forwa
     return xy;
 }
 
-
-static PJ_LP sterea_e_inverse (PJ_XY xy, PJ *P) {          /* Ellipsoidal, inverse */
-    PJ_LP lp = {0.0,0.0};
-    struct pj_opaque *Q = static_cast<struct pj_opaque*>(P->opaque);
+static PJ_LP sterea_e_inverse(PJ_XY xy, PJ *P) { /* Ellipsoidal, inverse */
+    PJ_LP lp = {0.0, 0.0};
+    struct pj_opaque *Q = static_cast<struct pj_opaque *>(P->opaque);
     double rho, c, sinc, cosc;
 
     xy.x /= P->k0;
     xy.y /= P->k0;
-    if ( (rho = hypot (xy.x, xy.y)) != 0.0 ) {
-        c = 2. * atan2 (rho, Q->R2);
-        sinc = sin (c);
-        cosc = cos (c);
-        lp.phi = asin (cosc * Q->sinc0 + xy.y * sinc * Q->cosc0 / rho);
-        lp.lam = atan2 (xy.x * sinc, rho * Q->cosc0 * cosc - xy.y * Q->sinc0 * sinc);
+    if ((rho = hypot(xy.x, xy.y)) != 0.0) {
+        c = 2. * atan2(rho, Q->R2);
+        sinc = sin(c);
+        cosc = cos(c);
+        lp.phi = asin(cosc * Q->sinc0 + xy.y * sinc * Q->cosc0 / rho);
+        lp.lam =
+            atan2(xy.x * sinc, rho * Q->cosc0 * cosc - xy.y * Q->sinc0 * sinc);
     } else {
         lp.phi = Q->phic0;
         lp.lam = 0.;
@@ -85,33 +81,32 @@ static PJ_LP sterea_e_inverse (PJ_XY xy, PJ *P) {          /* Ellipsoidal, inver
     return pj_inv_gauss(P->ctx, lp, Q->en);
 }
 
-
-static PJ *destructor (PJ *P, int errlev) {
-    if (nullptr==P)
+static PJ *destructor(PJ *P, int errlev) {
+    if (nullptr == P)
         return nullptr;
 
-    if (nullptr==P->opaque)
-        return pj_default_destructor (P, errlev);
+    if (nullptr == P->opaque)
+        return pj_default_destructor(P, errlev);
 
-    pj_dealloc (static_cast<struct pj_opaque*>(P->opaque)->en);
-    return pj_default_destructor (P, errlev);
+    free(static_cast<struct pj_opaque *>(P->opaque)->en);
+    return pj_default_destructor(P, errlev);
 }
 
-
-PJ *PROJECTION(sterea) {
+PJ *PJ_PROJECTION(sterea) {
     double R;
-    struct pj_opaque *Q = static_cast<struct pj_opaque*>(pj_calloc (1, sizeof (struct pj_opaque)));
+    struct pj_opaque *Q =
+        static_cast<struct pj_opaque *>(calloc(1, sizeof(struct pj_opaque)));
 
-    if (nullptr==Q)
-        return pj_default_destructor (P, ENOMEM);
+    if (nullptr == Q)
+        return pj_default_destructor(P, PROJ_ERR_OTHER /*ENOMEM*/);
     P->opaque = Q;
 
     Q->en = pj_gauss_ini(P->e, P->phi0, &(Q->phic0), &R);
-    if (nullptr==Q->en)
-        return pj_default_destructor (P, ENOMEM);
+    if (nullptr == Q->en)
+        return pj_default_destructor(P, PROJ_ERR_OTHER /*ENOMEM*/);
 
-    Q->sinc0 = sin (Q->phic0);
-    Q->cosc0 = cos (Q->phic0);
+    Q->sinc0 = sin(Q->phic0);
+    Q->cosc0 = cos(Q->phic0);
     Q->R2 = 2. * R;
 
     P->inv = sterea_e_inverse;
@@ -120,4 +115,3 @@ PJ *PROJECTION(sterea) {
 
     return P;
 }
-
