@@ -259,22 +259,6 @@ static PJ *setup_approx(PJ *P) {
 //
 /*****************************************************************************/
 
-/* Helper functions for "exact" transverse mercator */
-inline static double gatg(const double *p1, int len_p1, double B, double cos_2B,
-                          double sin_2B) {
-    double h = 0, h1, h2 = 0;
-
-    const double two_cos_2B = 2 * cos_2B;
-    const double *p = p1 + len_p1;
-    h1 = *--p;
-    while (p - p1) {
-        h = -h2 + two_cos_2B * h1 + *--p;
-        h2 = h1;
-        h1 = h;
-    }
-    return (B + h * sin_2B);
-}
-
 /* Complex Clenshaw summation */
 inline static double clenS(const double *a, int size, double sin_arg_r,
                            double cos_arg_r, double sinh_arg_i,
@@ -305,33 +289,13 @@ inline static double clenS(const double *a, int size, double sin_arg_r,
     return *R;
 }
 
-/* Real Clenshaw summation */
-static double clens(const double *a, int size, double arg_r) {
-    double r, hr, hr1, hr2, cos_arg_r;
-
-    const double *p = a + size;
-    cos_arg_r = cos(arg_r);
-    r = 2 * cos_arg_r;
-
-    /* summation loop */
-    hr1 = 0;
-    hr = *--p;
-    for (; a - p;) {
-        hr2 = hr1;
-        hr1 = hr;
-        hr = -hr2 + r * hr1 + *--p;
-    }
-    return sin(arg_r) * hr;
-}
-
 /* Ellipsoidal, forward */
 static PJ_XY exact_e_fwd(PJ_LP lp, PJ *P) {
     PJ_XY xy = {0.0, 0.0};
     const auto *Q = &(static_cast<struct tmerc_data *>(P->opaque)->exact);
 
     /* ell. LAT, LNG -> Gaussian LAT, LNG */
-    double Cn = gatg(Q->cbg, PROJ_ETMERC_ORDER, lp.phi, cos(2 * lp.phi),
-                     sin(2 * lp.phi));
+    double Cn = pj_auxlat_convert(lp.phi, Q->cbg, PROJ_ETMERC_ORDER);
     /* Gaussian LAT, LNG -> compl. sph. LAT */
     const double sin_Cn = sin(Cn);
     const double cos_Cn = cos(Cn);
@@ -462,20 +426,14 @@ static PJ_LP exact_e_inv(PJ_XY xy, PJ *P) {
          */
         const double sinhCe = sinh(Ce);
         Ce = atan2(sinhCe, cos_Cn);
-        const double modulus_Ce = hypot(sinhCe, cos_Cn);
+        const double modulus_Ce = hypot(sinhCe, cos_Cn),
+                     rr = hypot(sin_Cn, modulus_Ce);
         Cn = atan2(sin_Cn, modulus_Ce);
 #endif
 
         /* Gaussian LAT, LNG -> ell. LAT, LNG */
-
-        // Optimization of the computation of cos(2*Cn) and sin(2*Cn)
-        const double tmp = 2 * modulus_Ce / (sinhCe * sinhCe + 1);
-        const double sin_2_Cn = sin_Cn * tmp;
-        const double cos_2_Cn = tmp * modulus_Ce - 1.;
-        // const double cos_2_Cn = cos(2 * Cn);
-        // const double sin_2_Cn = sin(2 * Cn);
-
-        lp.phi = gatg(Q->cgb, PROJ_ETMERC_ORDER, Cn, cos_2_Cn, sin_2_Cn);
+        lp.phi = pj_auxlat_convert(Cn, sin_Cn / rr, modulus_Ce / rr, Q->cgb,
+                                   PROJ_ETMERC_ORDER);
         lp.lam = Ce;
     } else {
         proj_errno_set(P, PROJ_ERR_COORD_TRANSFM_OUTSIDE_PROJECTION_DOMAIN);
@@ -488,109 +446,37 @@ static PJ *setup_exact(PJ *P) {
     auto *Q = &(static_cast<struct tmerc_data *>(P->opaque)->exact);
 
     assert(P->es > 0);
-
+    static_assert(PROJ_ETMERC_ORDER == int(AuxLat::ORDER),
+                  "Inconsistent orders etmerc vs auxorder");
     /* third flattening */
     const double n = P->n;
-    double np = n;
+
+    // N.B., Engsager and Poder terminology (simplifying a little here...)
+    //   geodetic coordinates = geographic latitude
+    //   Soldner sphere + complex gaussian coordinates = conformal latitude
+    //   transverse Mercator coordinates = rectifying latitude
 
     /* COEF. OF TRIG SERIES GEO <-> GAUSS */
     /* cgb := Gaussian -> Geodetic, KW p190 - 191 (61) - (62) */
     /* cbg := Geodetic -> Gaussian, KW p186 - 187 (51) - (52) */
     /* PROJ_ETMERC_ORDER = 6th degree : Engsager and Poder: ICC2007 */
-
-    Q->cgb[0] =
-        n * (2 + n * (-2 / 3.0 +
-                      n * (-2 + n * (116 / 45.0 +
-                                     n * (26 / 45.0 + n * (-2854 / 675.0))))));
-    Q->cbg[0] =
-        n * (-2 +
-             n * (2 / 3.0 +
-                  n * (4 / 3.0 + n * (-82 / 45.0 +
-                                      n * (32 / 45.0 + n * (4642 / 4725.0))))));
-    np *= n;
-    Q->cgb[1] =
-        np * (7 / 3.0 +
-              n * (-8 / 5.0 + n * (-227 / 45.0 +
-                                   n * (2704 / 315.0 + n * (2323 / 945.0)))));
-    Q->cbg[1] =
-        np * (5 / 3.0 +
-              n * (-16 / 15.0 +
-                   n * (-13 / 9.0 + n * (904 / 315.0 + n * (-1522 / 945.0)))));
-    np *= n;
-    /* n^5 coeff corrected from 1262/105 -> -1262/105 */
-    Q->cgb[2] =
-        np * (56 / 15.0 +
-              n * (-136 / 35.0 + n * (-1262 / 105.0 + n * (73814 / 2835.0))));
-    Q->cbg[2] = np * (-26 / 15.0 +
-                      n * (34 / 21.0 + n * (8 / 5.0 + n * (-12686 / 2835.0))));
-    np *= n;
-    /* n^5 coeff corrected from 322/35 -> 332/35 */
-    Q->cgb[3] =
-        np * (4279 / 630.0 + n * (-332 / 35.0 + n * (-399572 / 14175.0)));
-    Q->cbg[3] = np * (1237 / 630.0 + n * (-12 / 5.0 + n * (-24832 / 14175.0)));
-    np *= n;
-    Q->cgb[4] = np * (4174 / 315.0 + n * (-144838 / 6237.0));
-    Q->cbg[4] = np * (-734 / 315.0 + n * (109598 / 31185.0));
-    np *= n;
-    Q->cgb[5] = np * (601676 / 22275.0);
-    Q->cbg[5] = np * (444337 / 155925.0);
-
+    pj_auxlat_coeffs(n, AuxLat::CONFORMAL, AuxLat::GEOGRAPHIC, Q->cgb);
+    pj_auxlat_coeffs(n, AuxLat::GEOGRAPHIC, AuxLat::CONFORMAL, Q->cbg);
     /* Constants of the projections */
     /* Transverse Mercator (UTM, ITM, etc) */
-    np = n * n;
     /* Norm. mer. quad, K&W p.50 (96), p.19 (38b), p.5 (2) */
-    Q->Qn =
-        P->k0 / (1 + n) * (1 + np * (1 / 4.0 + np * (1 / 64.0 + np / 256.0)));
+    Q->Qn = P->k0 * pj_rectifying_radius(n);
     /* coef of trig series */
     /* utg := ell. N, E -> sph. N, E,  KW p194 (65) */
     /* gtu := sph. N, E -> ell. N, E,  KW p196 (69) */
-    Q->utg[0] =
-        n *
-        (-0.5 +
-         n * (2 / 3.0 + n * (-37 / 96.0 +
-                             n * (1 / 360.0 + n * (81 / 512.0 +
-                                                   n * (-96199 / 604800.0))))));
-    Q->gtu[0] =
-        n * (0.5 + n * (-2 / 3.0 +
-                        n * (5 / 16.0 +
-                             n * (41 / 180.0 +
-                                  n * (-127 / 288.0 + n * (7891 / 37800.0))))));
-    Q->utg[1] =
-        np *
-        (-1 / 48.0 +
-         n * (-1 / 15.0 + n * (437 / 1440.0 +
-                               n * (-46 / 105.0 + n * (1118711 / 3870720.0)))));
-    Q->gtu[1] =
-        np *
-        (13 / 48.0 +
-         n * (-3 / 5.0 + n * (557 / 1440.0 +
-                              n * (281 / 630.0 + n * (-1983433 / 1935360.0)))));
-    np *= n;
-    Q->utg[2] =
-        np * (-17 / 480.0 +
-              n * (37 / 840.0 + n * (209 / 4480.0 + n * (-5569 / 90720.0))));
-    Q->gtu[2] =
-        np * (61 / 240.0 + n * (-103 / 140.0 + n * (15061 / 26880.0 +
-                                                    n * (167603 / 181440.0))));
-    np *= n;
-    Q->utg[3] =
-        np * (-4397 / 161280.0 + n * (11 / 504.0 + n * (830251 / 7257600.0)));
-    Q->gtu[3] = np * (49561 / 161280.0 +
-                      n * (-179 / 168.0 + n * (6601661 / 7257600.0)));
-    np *= n;
-    Q->utg[4] = np * (-4583 / 161280.0 + n * (108847 / 3991680.0));
-    Q->gtu[4] = np * (34729 / 80640.0 + n * (-3418889 / 1995840.0));
-    np *= n;
-    Q->utg[5] = np * (-20648693 / 638668800.0);
-    Q->gtu[5] = np * (212378941 / 319334400.0);
-
+    pj_auxlat_coeffs(n, AuxLat::RECTIFYING, AuxLat::CONFORMAL, Q->utg);
+    pj_auxlat_coeffs(n, AuxLat::CONFORMAL, AuxLat::RECTIFYING, Q->gtu);
     /* Gaussian latitude value of the origin latitude */
-    const double Z = gatg(Q->cbg, PROJ_ETMERC_ORDER, P->phi0, cos(2 * P->phi0),
-                          sin(2 * P->phi0));
+    const double Z = pj_auxlat_convert(P->phi0, Q->cbg, PROJ_ETMERC_ORDER);
 
     /* Origin northing minus true northing at the origin latitude */
     /* i.e. true northing = N - P->Zb                         */
-    Q->Zb = -Q->Qn * (Z + clens(Q->gtu, PROJ_ETMERC_ORDER, 2 * Z));
+    Q->Zb = -Q->Qn * pj_auxlat_convert(Z, Q->gtu, PROJ_ETMERC_ORDER);
 
     return P;
 }
